=======
History
=======

2.2.6 (2018-06-26)
------------------

* Update README with badges.
* Upgraded dependencies.
* Added several unit tests.

2.2.6 (2018-06-26)
------------------

* Fixed CI and added some tests around configuration.

2.2.5 (2018-06-25)
------------------

* Setup readthedocs.org.

2.2.4 (2018-06-25)
------------------

* Replaced packaging with cookiecutter-pypackage.
